/*******************************************************************************
* File Name: FastHiOut.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "FastHiOut.h"


/*******************************************************************************
* Function Name: FastHiOut_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void FastHiOut_Write(uint8 value) 
{
    uint8 staticBits = (FastHiOut_DR & (uint8)(~FastHiOut_MASK));
    FastHiOut_DR = staticBits | ((uint8)(value << FastHiOut_SHIFT) & FastHiOut_MASK);
}


/*******************************************************************************
* Function Name: FastHiOut_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  FastHiOut_DM_STRONG     Strong Drive 
*  FastHiOut_DM_OD_HI      Open Drain, Drives High 
*  FastHiOut_DM_OD_LO      Open Drain, Drives Low 
*  FastHiOut_DM_RES_UP     Resistive Pull Up 
*  FastHiOut_DM_RES_DWN    Resistive Pull Down 
*  FastHiOut_DM_RES_UPDWN  Resistive Pull Up/Down 
*  FastHiOut_DM_DIG_HIZ    High Impedance Digital 
*  FastHiOut_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void FastHiOut_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(FastHiOut_0, mode);
}


/*******************************************************************************
* Function Name: FastHiOut_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro FastHiOut_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 FastHiOut_Read(void) 
{
    return (FastHiOut_PS & FastHiOut_MASK) >> FastHiOut_SHIFT;
}


/*******************************************************************************
* Function Name: FastHiOut_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 FastHiOut_ReadDataReg(void) 
{
    return (FastHiOut_DR & FastHiOut_MASK) >> FastHiOut_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(FastHiOut_INTSTAT) 

    /*******************************************************************************
    * Function Name: FastHiOut_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 FastHiOut_ClearInterrupt(void) 
    {
        return (FastHiOut_INTSTAT & FastHiOut_MASK) >> FastHiOut_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
