/*******************************************************************************
* File Name: Fault_Out.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Fault_Out.h"


/*******************************************************************************
* Function Name: Fault_Out_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Fault_Out_Write(uint8 value) 
{
    uint8 staticBits = (Fault_Out_DR & (uint8)(~Fault_Out_MASK));
    Fault_Out_DR = staticBits | ((uint8)(value << Fault_Out_SHIFT) & Fault_Out_MASK);
}


/*******************************************************************************
* Function Name: Fault_Out_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Fault_Out_DM_STRONG     Strong Drive 
*  Fault_Out_DM_OD_HI      Open Drain, Drives High 
*  Fault_Out_DM_OD_LO      Open Drain, Drives Low 
*  Fault_Out_DM_RES_UP     Resistive Pull Up 
*  Fault_Out_DM_RES_DWN    Resistive Pull Down 
*  Fault_Out_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Fault_Out_DM_DIG_HIZ    High Impedance Digital 
*  Fault_Out_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Fault_Out_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Fault_Out_0, mode);
}


/*******************************************************************************
* Function Name: Fault_Out_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Fault_Out_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Fault_Out_Read(void) 
{
    return (Fault_Out_PS & Fault_Out_MASK) >> Fault_Out_SHIFT;
}


/*******************************************************************************
* Function Name: Fault_Out_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Fault_Out_ReadDataReg(void) 
{
    return (Fault_Out_DR & Fault_Out_MASK) >> Fault_Out_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Fault_Out_INTSTAT) 

    /*******************************************************************************
    * Function Name: Fault_Out_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Fault_Out_ClearInterrupt(void) 
    {
        return (Fault_Out_INTSTAT & Fault_Out_MASK) >> Fault_Out_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
