/*******************************************************************************
* File Name: StatusBit.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "StatusBit.h"


/*******************************************************************************
* Function Name: StatusBit_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void StatusBit_Write(uint8 value) 
{
    uint8 staticBits = (StatusBit_DR & (uint8)(~StatusBit_MASK));
    StatusBit_DR = staticBits | ((uint8)(value << StatusBit_SHIFT) & StatusBit_MASK);
}


/*******************************************************************************
* Function Name: StatusBit_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  StatusBit_DM_STRONG     Strong Drive 
*  StatusBit_DM_OD_HI      Open Drain, Drives High 
*  StatusBit_DM_OD_LO      Open Drain, Drives Low 
*  StatusBit_DM_RES_UP     Resistive Pull Up 
*  StatusBit_DM_RES_DWN    Resistive Pull Down 
*  StatusBit_DM_RES_UPDWN  Resistive Pull Up/Down 
*  StatusBit_DM_DIG_HIZ    High Impedance Digital 
*  StatusBit_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void StatusBit_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(StatusBit_0, mode);
}


/*******************************************************************************
* Function Name: StatusBit_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro StatusBit_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 StatusBit_Read(void) 
{
    return (StatusBit_PS & StatusBit_MASK) >> StatusBit_SHIFT;
}


/*******************************************************************************
* Function Name: StatusBit_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 StatusBit_ReadDataReg(void) 
{
    return (StatusBit_DR & StatusBit_MASK) >> StatusBit_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(StatusBit_INTSTAT) 

    /*******************************************************************************
    * Function Name: StatusBit_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 StatusBit_ClearInterrupt(void) 
    {
        return (StatusBit_INTSTAT & StatusBit_MASK) >> StatusBit_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
