/*******************************************************************************
* File Name: myFast.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "myFast.h"


/*******************************************************************************
* Function Name: myFast_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void myFast_Write(uint8 value) 
{
    uint8 staticBits = (myFast_DR & (uint8)(~myFast_MASK));
    myFast_DR = staticBits | ((uint8)(value << myFast_SHIFT) & myFast_MASK);
}


/*******************************************************************************
* Function Name: myFast_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  myFast_DM_STRONG     Strong Drive 
*  myFast_DM_OD_HI      Open Drain, Drives High 
*  myFast_DM_OD_LO      Open Drain, Drives Low 
*  myFast_DM_RES_UP     Resistive Pull Up 
*  myFast_DM_RES_DWN    Resistive Pull Down 
*  myFast_DM_RES_UPDWN  Resistive Pull Up/Down 
*  myFast_DM_DIG_HIZ    High Impedance Digital 
*  myFast_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void myFast_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(myFast_0, mode);
}


/*******************************************************************************
* Function Name: myFast_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro myFast_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 myFast_Read(void) 
{
    return (myFast_PS & myFast_MASK) >> myFast_SHIFT;
}


/*******************************************************************************
* Function Name: myFast_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 myFast_ReadDataReg(void) 
{
    return (myFast_DR & myFast_MASK) >> myFast_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(myFast_INTSTAT) 

    /*******************************************************************************
    * Function Name: myFast_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 myFast_ClearInterrupt(void) 
    {
        return (myFast_INTSTAT & myFast_MASK) >> myFast_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
