/*******************************************************************************
* File Name: myRmon.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "myRmon.h"


/*******************************************************************************
* Function Name: myRmon_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void myRmon_Write(uint8 value) 
{
    uint8 staticBits = (myRmon_DR & (uint8)(~myRmon_MASK));
    myRmon_DR = staticBits | ((uint8)(value << myRmon_SHIFT) & myRmon_MASK);
}


/*******************************************************************************
* Function Name: myRmon_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  myRmon_DM_STRONG     Strong Drive 
*  myRmon_DM_OD_HI      Open Drain, Drives High 
*  myRmon_DM_OD_LO      Open Drain, Drives Low 
*  myRmon_DM_RES_UP     Resistive Pull Up 
*  myRmon_DM_RES_DWN    Resistive Pull Down 
*  myRmon_DM_RES_UPDWN  Resistive Pull Up/Down 
*  myRmon_DM_DIG_HIZ    High Impedance Digital 
*  myRmon_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void myRmon_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(myRmon_0, mode);
}


/*******************************************************************************
* Function Name: myRmon_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro myRmon_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 myRmon_Read(void) 
{
    return (myRmon_PS & myRmon_MASK) >> myRmon_SHIFT;
}


/*******************************************************************************
* Function Name: myRmon_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 myRmon_ReadDataReg(void) 
{
    return (myRmon_DR & myRmon_MASK) >> myRmon_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(myRmon_INTSTAT) 

    /*******************************************************************************
    * Function Name: myRmon_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 myRmon_ClearInterrupt(void) 
    {
        return (myRmon_INTSTAT & myRmon_MASK) >> myRmon_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
